@@ -87,6 +87,7 @@ class AdminClientABC(abc.ABC):
         name: str,
         default_credits: Decimal | None = None,
         default_quota: Quota = Quota(),
+        default_role: ClusterUserRoleType = ClusterUserRoleType.USER,
     ) -> Cluster:
         ...
 
@@ -427,7 +428,8 @@ class AdminClientABC(abc.ABC):
         balance: Balance = Balance(),
         default_quota: Quota = Quota(),
         default_credits: Decimal | None = None,
-        storage_size_mb: int | None = None,
+        default_role: ClusterUserRoleType = ClusterUserRoleType.USER,
+        storage_size: int | None = None,
     ) -> OrgCluster:
         ...
 
@@ -462,6 +464,7 @@ class AdminClientABC(abc.ABC):
         org_name: str,
         default_quota: Quota = Quota(),
         default_credits: Decimal | None = None,
+        default_role: ClusterUserRoleType = ClusterUserRoleType.USER,
     ) -> OrgCluster:
         ...
 
@@ -738,6 +741,8 @@ class AdminClientBase:
             if payload.get("default_credits")
             else None,
             default_quota=self._parse_quota(payload.get("default_quota")),
+            default_role=ClusterUserRoleType(payload["default_role"]),
+            maintenance=payload["maintenance"],
         )
 
     async def list_clusters(self) -> list[Cluster]:
@@ -760,10 +765,14 @@ class AdminClientBase:
         name: str,
         default_credits: Decimal | None = None,
         default_quota: Quota = Quota(),
+        default_role: ClusterUserRoleType = ClusterUserRoleType.USER,
+        maintenance: bool = False,
     ) -> Cluster:
         payload: dict[str, Any] = {
             "name": name,
             "default_quota": {},
+            "default_role": str(default_role),
+            "maintenance": maintenance,
         }
         if default_credits:
             payload["default_credits"] = str(default_credits)
@@ -782,6 +791,8 @@ class AdminClientBase:
     ) -> None:
         payload: dict[str, Any] = {
             "name": cluster.name,
+            "maintenance": cluster.maintenance,
+            "default_role": str(cluster.default_role),
         }
         if cluster.default_credits:
             payload["default_credits"] = str(cluster.default_credits)
@@ -1342,7 +1353,9 @@ class AdminClientBase:
             if payload.get("default_credits")
             else None,
             default_quota=self._parse_quota(payload.get("default_quota")),
-            storage_size_mb=payload.get("storage_size_mb"),
+            default_role=ClusterUserRoleType(payload["default_role"]),
+            storage_size=payload.get("storage_size"),
+            maintenance=payload["maintenance"],
         )
 
     async def create_org_cluster(
@@ -1353,13 +1366,17 @@ class AdminClientBase:
         balance: Balance = Balance(),
         default_quota: Quota = Quota(),
         default_credits: Decimal | None = None,
-        storage_size_mb: int | None = None,
+        default_role: ClusterUserRoleType = ClusterUserRoleType.USER,
+        storage_size: int | None = None,
+        maintenance: bool = False,
     ) -> OrgCluster:
         payload: dict[str, Any] = {
             "org_name": org_name,
             "quota": {},
             "balance": {},
             "default_quota": {},
+            "default_role": str(default_role),
+            "maintenance": maintenance,
         }
         if quota.total_running_jobs is not None:
             payload["quota"]["total_running_jobs"] = quota.total_running_jobs
@@ -1373,8 +1390,8 @@ class AdminClientBase:
             payload["default_quota"][
                 "total_running_jobs"
             ] = default_quota.total_running_jobs
-        if storage_size_mb is not None:
-            payload["storage_size_mb"] = storage_size_mb
+        if storage_size is not None:
+            payload["storage_size"] = storage_size
         async with self._request(
             "POST",
             f"clusters/{cluster_name}/orgs",
@@ -1415,6 +1432,8 @@ class AdminClientBase:
             "quota": {},
             "balance": {},
             "default_quota": {},
+            "default_role": str(org_cluster.default_role),
+            "maintenance": org_cluster.maintenance,
         }
         if org_cluster.quota.total_running_jobs is not None:
             payload["quota"][
@@ -1454,9 +1473,11 @@ class AdminClientBase:
         org_name: str,
         default_quota: Quota = Quota(),
         default_credits: Decimal | None = None,
+        default_role: ClusterUserRoleType = ClusterUserRoleType.USER,
     ) -> OrgCluster:
         payload: dict[str, Any] = {
             "quota": {},
+            "default_role": str(default_role),
         }
         if default_credits:
             payload["credits"] = str(default_credits)
@@ -1851,7 +1872,12 @@ class AdminClientDummy(AdminClientABC):
         name="user",
         email="email@example.com",
     )
-    DUMMY_CLUSTER = Cluster(name="default", default_credits=None, default_quota=Quota())
+    DUMMY_CLUSTER = Cluster(
+        name="default",
+        default_credits=None,
+        default_quota=Quota(),
+        default_role=ClusterUserRoleType.USER,
+    )
     DUMMY_CLUSTER_USER = ClusterUserWithInfo(
         cluster_name="default",
         user_name="user",
@@ -1869,7 +1895,7 @@ class AdminClientDummy(AdminClientABC):
         cluster_name="default",
         balance=Balance(),
         quota=Quota(),
-        storage_size_mb=1024,
+        storage_size=1024,
     )
     DUMMY_ORG_USER = OrgUserWithInfo(
         org_name="org",
@@ -1922,6 +1948,7 @@ class AdminClientDummy(AdminClientABC):
         name: str,
         default_credits: Decimal | None = None,
         default_quota: Quota = Quota(),
+        default_role: ClusterUserRoleType = ClusterUserRoleType.USER,
     ) -> Cluster:
         return self.DUMMY_CLUSTER
 
@@ -2250,7 +2277,8 @@ class AdminClientDummy(AdminClientABC):
         balance: Balance = Balance(),
         default_quota: Quota = Quota(),
         default_credits: Decimal | None = None,
-        storage_size_mb: int | None = None,
+        default_role: ClusterUserRoleType = ClusterUserRoleType.USER,
+        storage_size: int | None = None,
     ) -> OrgCluster:
         return self.DUMMY_ORG_CLUSTER
 
@@ -2280,6 +2308,7 @@ class AdminClientDummy(AdminClientABC):
         org_name: str,
         default_quota: Quota = Quota(),
         default_credits: Decimal | None = None,
+        default_role: ClusterUserRoleType = ClusterUserRoleType.USER,
     ) -> OrgCluster:
         return self.DUMMY_ORG_CLUSTER
 
